#include <linux/types.h>
#include <linux/delay.h>
#include <asm/io.h>

#include <linux/version.h>
#include <asm/uaccess.h>

#include "video_decoder.h"
#include "zr36120.h"

/* ----------------------------------------------------------------------- */
/* I2C functions							   */
/* ----------------------------------------------------------------------- */

/* software I2C functions */

#define I2C_DELAY   10

static void i2c_setlines(struct i2c_bus *bus,int ctrl,int data)
{
	struct zoran *ztv = (struct zoran*)bus->data;
	unsigned int b = 0;
	if (data) b |= ZORAN_I2C_SCL;
	if (ctrl) b |= ZORAN_I2C_SDA;
	zrwrite(b, ZORAN_I2C);
	udelay(I2C_DELAY);
}

static int i2c_getdataline(struct i2c_bus *bus)
{
	struct zoran *ztv = (struct zoran*)bus->data;
	return zrread(ZORAN_I2C) & ZORAN_I2C_SCL;
}

static
void attach_inform(struct i2c_bus *bus, int id)
{
	struct zoran *ztv = (struct zoran*)bus->data;

	switch (id) {
	 case I2C_DRIVERID_DECODER:
		ztv->have_decoder = 1;
		DEBUG(printk(KERN_INFO "zoran: decoder attached\n"));
		break;
	 default:
		DEBUG(printk(KERN_INFO "zoran: attach_inform; unknown device id=%d\n",id));
		break;
	}
}

static
void detach_inform(struct i2c_bus *bus, int id)
{
	struct zoran *ztv = (struct zoran*)bus->data;

	switch (id) {
	 case I2C_DRIVERID_TUNER:
		ztv->have_decoder = 0;
		DEBUG(printk(KERN_INFO "zoran: mux detached\n"));
		break;
	 default:
		DEBUG(printk(KERN_INFO "zoran: detach_inform; unknown device id=%d\n",id));
		break;
	}
}

struct i2c_bus zoran_i2c_bus_template =
{
	"ZR36120",
	I2C_BUSID_ZORAN,
	NULL,

	SPIN_LOCK_UNLOCKED,

	attach_inform,
	detach_inform,

	i2c_setlines,
	i2c_getdataline,
	NULL,
	NULL,
};
